# mh_universal_functions

mh_universal_functions is a Python library currently used in Python programs pir.py and rha.py.
(see https://www.makeareadme.com/ for examples of README.md)

## Installation

Use the package manager [pip](https://pypi.org/project/mh-universal-functions) to install mh_universal_functions.

```bash
sudo /usr/local/bin/python3.7 -m pip install mh-universal-functions==2020.6.27.1
```

## Usage

```python
import mh_universal_functions

mh_universal_functions.test() # returns 'Hello world of PyPI'
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)